@@ -29,12 +29,27 @@ def eq_sql(a, b):
 
 
 class TestWKTElement:
+    _srid = 3857  # expected srid
+    _wkt = "POINT (1 2)"  # expected wkt
+    _ewkt = "SRID=3857;POINT (1 2)"  # expected ewkt
+
+    def test_ctor(self):
+        e1 = WKTElement(self._wkt)
+        e2 = WKTElement(self._wkt, extended=False)
+        e3 = WKTElement(self._wkt, srid=self._srid)
+        e4 = WKTElement(self._wkt, srid=self._srid, extended=True)
+        e5 = WKTElement(self._wkt, srid=self._srid, extended=False)
+        assert e1.desc == e2.desc == e3.desc == e4.desc == e5.desc == self._wkt
+        assert e1.srid == e2.srid == -1
+        assert e3.srid == e4.srid == e5.srid == self._srid
+        assert e1.extended == e2.extended == e3.extended == (not e4.extended) == e5.extended
+
     def test_desc(self):
-        e = WKTElement("POINT(1 2)")
-        assert e.desc == "POINT(1 2)"
+        e = WKTElement(self._wkt)
+        assert e.desc == self._wkt
 
     def test_function_call(self):
-        e = WKTElement("POINT(1 2)")
+        e = WKTElement(self._wkt)
         f = e.ST_Buffer(2)
         eq_sql(
             f,
@@ -44,50 +59,87 @@ class TestWKTElement:
         )
         assert f.compile().params == {
             "ST_Buffer_1": 2,
-            "ST_GeomFromText_1": "POINT(1 2)",
+            "ST_GeomFromText_1": self._wkt,
             "ST_GeomFromText_2": -1,
         }
 
     def test_attribute_error(self):
-        e = WKTElement("POINT(1 2)")
+        e = WKTElement(self._wkt)
         assert not hasattr(e, "foo")
 
     def test_pickle_unpickle(self):
         import pickle
 
-        e = WKTElement("POINT(1 2)", srid=3, extended=True)
+        e = WKTElement(self._wkt, srid=3, extended=False)
         pickled = pickle.dumps(e)
         unpickled = pickle.loads(pickled)
         assert unpickled.srid == 3
-        assert unpickled.extended is True
-        assert unpickled.data == "POINT(1 2)"
+        assert unpickled.extended is False
+        assert unpickled.data == self._wkt
         f = unpickled.ST_Buffer(2)
-        eq_sql(f, "ST_Buffer(" "ST_GeomFromEWKT(:ST_GeomFromEWKT_1), " ":ST_Buffer_1)")
+        eq_sql(
+            f,
+            "ST_Buffer("
+            "ST_GeomFromText(:ST_GeomFromText_1, :ST_GeomFromText_2), "
+            ":ST_Buffer_1)",
+        )
         assert f.compile().params == {
             "ST_Buffer_1": 2,
-            "ST_GeomFromEWKT_1": "POINT(1 2)",
+            "ST_GeomFromText_1": self._wkt,
+            "ST_GeomFromText_2": 3,
         }
 
     def test_eq(self):
-        a = WKTElement("POINT(1 2)")
-        b = WKTElement("POINT(1 2)")
+        a = WKTElement(self._wkt)
+        b = WKTElement(self._wkt)
         assert a == b
 
     def test_hash(self):
-        a = WKTElement("POINT(1 2)")
+        a = WKTElement(self._wkt)
         b = WKTElement("POINT(10 20)")
         c = WKTElement("POINT(10 20)")
         assert set([a, b, c]) == set([a, b, c])
         assert len(set([a, b, c])) == 2
 
+    def test_as_wkt_as_ewkt(self):
+        e1 = WKTElement(self._wkt)
+        e2 = WKTElement(self._wkt, srid=self._srid)
+
+        # No SRID
+        e3 = e1.as_ewkt()
+        assert e3.desc == self._wkt
+        assert e3.srid == -1
+        assert e3.extended is False
+
+        # With SRID
+        e4 = e2.as_ewkt()
+        assert e4.desc == f"SRID={self._srid};{self._wkt}"
+        assert e4.srid == self._srid
+        assert e4.extended is True
+
+        assert e3.as_wkt() == e3.as_wkt().as_wkt() == e1
+        assert e4.as_wkt() == e4.as_wkt().as_wkt() == e2
+
 
 class TestExtendedWKTElement:
     _srid = 3857  # expected srid
     _wkt = "POINT (1 2 3)"  # expected wkt
     _ewkt = "SRID=3857;POINT (1 2 3)"  # expected ewkt
 
+    def test_ctor(self):
+        arbitrary_srid = self._srid + 1
+        e1 = WKTElement(self._ewkt)
+        e2 = WKTElement(self._ewkt, extended=True)
+        e3 = WKTElement(self._ewkt, srid=arbitrary_srid)
+        e4 = WKTElement(self._ewkt, srid=arbitrary_srid, extended=True)
+        e5 = WKTElement(self._ewkt, srid=arbitrary_srid, extended=False)
+        assert e1.desc == e2.desc == e3.desc == e4.desc == e5.desc == self._ewkt
+        assert e1.srid == e2.srid == self._srid
+        assert e3.srid == e4.srid == e5.srid == arbitrary_srid
+        assert e1.extended == e2.extended == e3.extended == e4.extended == (not e5.extended)
+
     def test_desc(self):
-        e = WKTElement(self._ewkt, extended=True)
+        e = WKTElement(self._ewkt)
         assert e.desc == self._ewkt
 
     def test_function_call(self):
@@ -129,6 +181,10 @@ class TestExtendedWKTElement:
     def test_unpack_srid_from_bad_ewkt(self):
         with pytest.raises(ArgumentError):
             WKTElement("SRID=BAD SRID;POINT (1 2 3)", extended=True)
+        with pytest.raises(ArgumentError):
+            WKTElement("SRID=BAD SRID;POINT (1 2 3)", extended=True)
+        with pytest.raises(ArgumentError):
+            WKTElement("SRID=1234;1234;1234;POINT (1 2 3)", extended=True)
 
     def test_eq(self):
         a = WKTElement(self._ewkt, extended=True)
@@ -150,6 +206,26 @@ class TestExtendedWKTElement:
         with pytest.raises(ArgumentError, match="invalid EWKT string"):
             WKTElement("SRID=3857" + self._wkt, extended=True)
 
+    def test_as_wkt_as_ewkt(self):
+        arbitrary_srid = self._srid + 1
+        e1 = WKTElement(self._ewkt)
+        e2 = WKTElement(self._ewkt, srid=arbitrary_srid)
+
+        # No arbitrary SRID
+        e3 = e1.as_wkt()
+        assert e3.desc == self._wkt
+        assert e3.srid == self._srid
+        assert e3.extended is False
+        assert e3.as_ewkt() == e1
+
+        # With arbitrary SRID
+        e4 = e2.as_wkt()
+        assert e4.desc == self._wkt
+        assert e4.srid == arbitrary_srid
+        assert e4.extended is False
+        # The arbitrary SRID overwrites the original SRID in the EWKT string
+        assert e4.as_ewkt() == WKTElement(f"SRID={arbitrary_srid};{self._wkt}")
+
 
 class TestWKTElementFunction:
     def test_ST_Equal_WKTElement_WKTElement(self):
@@ -209,49 +285,55 @@ class TestExtendedWKTElementFunction:
 class TestExtendedWKBElement:
     # _bin/_hex computed by following query:
     # SELECT ST_GeomFromEWKT('SRID=3;POINT(1 2)');
-    _bin = memoryview(
+    _bin_ewkb = memoryview(
         b"\x01\x01\x00\x00 \x03\x00\x00\x00\x00\x00\x00"
         b"\x00\x00\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@"
     )
-    _hex = str("010100002003000000000000000000f03f0000000000000040")
+    _bin_wkb = memoryview(
+        b"\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@"
+    )
+    _hex_ewkb = str("010100002003000000000000000000f03f0000000000000040")
+    _hex_wkb = str("0101000000000000000000f03f0000000000000040")
     _srid = 3  # expected srid
     _wkt = "POINT (1 2)"  # expected wkt
 
     def test_desc(self):
-        e = WKBElement(self._bin, extended=True)
-        assert e.desc == self._hex
+        e1 = WKBElement(self._bin_ewkb, extended=True)
+        e2 = WKBElement(self._bin_ewkb)
+        assert e1.desc == self._hex_ewkb
+        assert e2.desc == self._hex_ewkb
 
     def test_desc_str(self):
-        e = WKBElement(self._hex)
-        assert e.desc == self._hex
+        e = WKBElement(self._hex_ewkb)
+        assert e.desc == self._hex_ewkb
 
     def test_function_call(self):
-        e = WKBElement(self._bin, extended=True)
+        e = WKBElement(self._bin_ewkb, extended=True)
         f = e.ST_Buffer(2)
         eq_sql(f, "ST_Buffer(" "ST_GeomFromEWKB(:ST_GeomFromEWKB_1), " ":ST_Buffer_1)")
         assert f.compile().params == {
             "ST_Buffer_1": 2,
-            "ST_GeomFromEWKB_1": self._bin,
+            "ST_GeomFromEWKB_1": self._bin_ewkb,
         }
 
     def test_function_str(self):
-        e = WKBElement(self._bin, extended=True)
+        e = WKBElement(self._bin_ewkb, extended=True)
         assert isinstance(str(e), str)
 
     def test_pickle_unpickle(self):
         import pickle
 
-        e = WKBElement(self._bin, srid=self._srid, extended=True)
+        e = WKBElement(self._bin_ewkb, srid=self._srid, extended=True)
         pickled = pickle.dumps(e)
         unpickled = pickle.loads(pickled)
         assert unpickled.srid == self._srid
         assert unpickled.extended is True
-        assert unpickled.data == bytes(self._bin)
+        assert unpickled.data == bytes(self._bin_ewkb)
         f = unpickled.ST_Buffer(2)
         eq_sql(f, "ST_Buffer(" "ST_GeomFromEWKB(:ST_GeomFromEWKB_1), " ":ST_Buffer_1)")
         assert f.compile().params == {
             "ST_Buffer_1": 2,
-            "ST_GeomFromEWKB_1": bytes(self._bin),
+            "ST_GeomFromEWKB_1": bytes(self._bin_ewkb),
         }
 
     def test_unpack_srid_from_bin(self):
@@ -259,23 +341,23 @@ class TestExtendedWKBElement:
         Unpack SRID from WKB struct (when it is not provided as arg)
         to ensure geometry result processor preserves query SRID.
         """
-        e = WKBElement(self._bin, extended=True)
+        e = WKBElement(self._bin_ewkb, extended=True)
         assert e.srid == self._srid
         assert wkb.loads(bytes(e.data)).wkt == self._wkt
 
     def test_unpack_srid_from_bin_forcing_srid(self):
-        e = WKBElement(self._bin, srid=9999, extended=True)
+        e = WKBElement(self._bin_ewkb, srid=9999, extended=True)
         assert e.srid == 9999
         assert wkb.loads(bytes(e.data)).wkt == self._wkt
 
     def test_unpack_srid_from_hex(self):
-        e = WKBElement(self._hex, extended=True)
+        e = WKBElement(self._hex_ewkb, extended=True)
         assert e.srid == self._srid
         assert wkb.loads(e.data, hex=True).wkt == self._wkt
 
     def test_eq(self):
-        a = WKBElement(self._bin, extended=True)
-        b = WKBElement(self._bin, extended=True)
+        a = WKBElement(self._bin_ewkb, extended=True)
+        b = WKBElement(self._bin_ewkb, extended=True)
         assert a == b
 
     def test_hash(self):
@@ -285,6 +367,49 @@ class TestExtendedWKBElement:
         assert set([a, b, c]) == set([a, b, c])
         assert len(set([a, b, c])) == 2
 
+    def test_as_wkt_as_ewkt(self):
+        arbitrary_srid = self._srid + 1
+        e1 = WKBElement(self._bin_ewkb)
+        e2 = WKBElement(self._bin_ewkb, srid=arbitrary_srid)
+        e3 = WKBElement(self._hex_ewkb)
+        e4 = WKBElement(self._hex_ewkb, srid=arbitrary_srid)
+
+        # Bin with no arbitrary SRID
+        e5 = e1.as_wkb()
+        assert e5.desc == self._hex_wkb
+        assert e5.srid == self._srid
+        assert e5.extended is False
+        assert e5.as_ewkb() == e1
+
+        # Bin with arbitrary SRID
+        e6 = e2.as_wkb()
+        assert e6.desc == self._hex_wkb
+        assert e6.srid == arbitrary_srid
+        assert e6.extended is False
+        # The arbitrary SRID overwrites the original SRID in the EWKB string
+        e6_ewkb = WKBElement(self._bin_ewkb, srid=arbitrary_srid)
+        data = bytearray(e6_ewkb.data)
+        data[5] = 4
+        e6_ewkb.data = memoryview(data)
+        assert e6.as_ewkb() == e6_ewkb
+
+        # Hex with no arbitrary SRID
+        e7 = e3.as_wkb()
+        assert e7.desc == self._hex_wkb
+        assert e7.srid == self._srid
+        assert e7.extended is False
+        assert e7.as_ewkb() == e3
+
+        # Hex with arbitrary SRID
+        e8 = e4.as_wkb()
+        assert e8.desc == self._hex_wkb
+        assert e8.srid == arbitrary_srid
+        assert e8.extended is False
+        # The arbitrary SRID overwrites the original SRID in the EWKB string
+        e8_ewkb = WKBElement(self._hex_ewkb, srid=arbitrary_srid)
+        e8_ewkb.data = e8_ewkb.data[:11] + "4" + e8_ewkb.data[12:]
+        assert e8.as_ewkb() == e8_ewkb
+
 
 class TestWKBElement:
     def test_desc(self):
