@@ -1,8 +1,11 @@
 import re
+from pathlib import Path
 
+from sqlalchemy import select
 from sqlalchemy.sql import func
 
-import geoalchemy2.functions  # NOQA
+import geoalchemy2.functions
+from geoalchemy2._functions_helpers import _generate_stubs
 from geoalchemy2.types import Raster  # NOQA
 
 #
@@ -44,6 +47,22 @@ def _test_raster_returning_func(name, *args, **kwargs):
     )
 
 
+def test_stubs_up_to_date() -> None:
+    geoalchemy2_path = Path(geoalchemy2.__file__).parent
+    current_stubs = (geoalchemy2_path / "functions.pyi").read_text()
+    generated_stubs = _generate_stubs()
+    assert current_stubs == generated_stubs
+
+
+def test_predefined_function() -> None:
+    geom = geoalchemy2.functions.ST_GeomFromText("POINT(0, 0)")
+    eq_sql(
+        select(geoalchemy2.functions.ST_Buffer(geom, 1.0)),
+        "SELECT ST_AsEWKB(ST_Buffer(ST_GeomFromText(:ST_GeomFromText_1), "
+        ':ST_Buffer_2)) AS "ST_Buffer_1"',
+    )
+
+
 #
 # Geometry Constructors
 #
