@@ -12,7 +12,7 @@ metadata = MetaData()
 Base = declarative_base(metadata=metadata)
 
 
-class PickledLake(Base):
+class PickledLake(Base):  # type: ignore
     __tablename__ = "pickled_lake"
     id = Column(Integer, primary_key=True)
     geom = Column(Geometry(geometry_type="LINESTRING", srid=4326))
@@ -38,12 +38,12 @@ class TestPickle:
         session.rollback()
         metadata.drop_all(session.bind, checkfirst=True)
 
-    def test_pickle_unpickle(self, session, setup_one_lake):
+    def test_pickle_unpickle(self, session, setup_one_lake, dialect_name):
         import pickle
 
         lake_id = setup_one_lake
 
-        lake = session.query(PickledLake).get(lake_id)
+        lake = session.get(PickledLake, lake_id)
         assert isinstance(lake.geom, WKBElement)
         data_desc = str(lake.geom)
 
@@ -51,4 +51,7 @@ class TestPickle:
         unpickled = pickle.loads(pickled)
         assert unpickled.geom.srid == 4326
         assert str(unpickled.geom) == data_desc
-        assert unpickled.geom.extended is True
+        if dialect_name == "mysql":
+            assert unpickled.geom.extended is False
+        else:
+            assert unpickled.geom.extended is True
