@@ -9,8 +9,9 @@ from geoalchemy2.shape import to_shape
 
 def test_to_shape_WKBElement():
     # POINT(1 2)
-    e = WKBElement(b'\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00'
-                   b'\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@')
+    e = WKBElement(
+        b"\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00" b"\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@"
+    )
     s = to_shape(e)
     assert isinstance(s, Point)
     assert s.x == 1
@@ -19,7 +20,7 @@ def test_to_shape_WKBElement():
 
 def test_to_shape_WKBElement_str():
     # POINT(1 2)
-    e = WKBElement(str('0101000000000000000000f03f0000000000000040'))
+    e = WKBElement(str("0101000000000000000000f03f0000000000000040"))
     s = to_shape(e)
     assert isinstance(s, Point)
     assert s.x == 1
@@ -28,10 +29,12 @@ def test_to_shape_WKBElement_str():
 
 def test_to_shape_ExtendedWKBElement():
     # SRID=3857;POINT(1 2 3)
-    e = WKBElement(b'\x01\x01\x00\x00\xa0\x11\x0f\x00\x00\x00'
-                   b'\x00\x00\x00\x00\x00\xf0?\x00\x00\x00\x00'
-                   b'\x00\x00\x00@\x00\x00\x00\x00\x00\x00\x08@',
-                   extended=True)
+    e = WKBElement(
+        b"\x01\x01\x00\x00\xa0\x11\x0f\x00\x00\x00"
+        b"\x00\x00\x00\x00\x00\xf0?\x00\x00\x00\x00"
+        b"\x00\x00\x00@\x00\x00\x00\x00\x00\x00\x08@",
+        extended=True,
+    )
     s = to_shape(e)
     assert isinstance(s, Point)
     assert s.x == 1
@@ -40,7 +43,7 @@ def test_to_shape_ExtendedWKBElement():
 
 
 def test_to_shape_ExtendedWKTElement():
-    e = WKTElement('SRID=3857;POINT(1 2)', extended=True)
+    e = WKTElement("SRID=3857;POINT(1 2)", extended=True)
     s = to_shape(e)
     assert isinstance(s, Point)
     assert s.x == 1
@@ -48,7 +51,7 @@ def test_to_shape_ExtendedWKTElement():
 
 
 def test_to_shape_WKTElement():
-    e = WKTElement('POINT(1 2)')
+    e = WKTElement("POINT(1 2)")
     s = to_shape(e)
     assert isinstance(s, Point)
     assert s.x == 1
@@ -57,7 +60,7 @@ def test_to_shape_WKTElement():
 
 def test_from_shape():
     # Standard case: POINT(1 2)
-    expected = WKBElement(str('0101000000000000000000f03f0000000000000040'))
+    expected = WKBElement(str("0101000000000000000000f03f0000000000000040"))
     p = Point(1, 2)
     e = from_shape(p)
     assert isinstance(e, WKBElement)
@@ -69,7 +72,7 @@ def test_from_shape():
     assert s.equals(p)
 
     # Standard case with SRID: SRID=2145;POINT(1 2)
-    expected2 = WKBElement(str('0101000000000000000000f03f0000000000000040'), srid=2154)
+    expected2 = WKBElement(str("0101000000000000000000f03f0000000000000040"), srid=2154)
     p = Point(1, 2)
     e2 = from_shape(p, srid=2154)
     assert isinstance(e2, WKBElement)
@@ -81,9 +84,7 @@ def test_from_shape():
     assert s2.equals(p)
 
     # Extended case: SRID=2145;POINT(1 2)
-    expected3 = WKBElement(
-        str('01010000206a080000000000000000f03f0000000000000040'),
-        extended=True)
+    expected3 = WKBElement(str("01010000206a080000000000000000f03f0000000000000040"), extended=True)
     e3 = from_shape(p, srid=2154, extended=True)
     assert isinstance(e3, WKBElement)
     assert isinstance(e3.data, memoryview)
